@@ -22,7 +22,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
-    KLocalizedString::setApplicationDomain("kjumpingcube");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kjumpingcube"));
 
     KAboutData aboutData( QStringLiteral("kjumpingcube"), i18n("KJumpingCube"),
                           QStringLiteral(KJUMPINGCUBE_VERSION_STRING),
@@ -41,15 +41,17 @@ int main(int argc, char *argv[])
                       i18n("Graphics for KDE 4.0 version."),
                       QStringLiteral("irs_me@hotmail.com"));
 
-    QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kjumpingcube")));
+
     KCrash::initialize();
+
+    QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
-    KDBusService service;
 
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kjumpingcube")));
+    KDBusService service;
 
     // All session management is handled in the RESTORE macro
     if (app.isSessionRestored()) {
